# Copyright 2016  Lars Wirzenius
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# =*= License: GPL-3+ =*=


import email
import unittest

import distixlib


class MessageThreadTests(unittest.TestCase):

    def make_message(self, date):
        return email.message_from_string(
            'Date: {}\nFrom: user@example.com\n\nbody\n'.format(date))

    def test_has_no_messages_initially(self):
        thread = distixlib.MessageThread()
        self.assertEqual(thread.get_messages_in_date_order(), [])

    def test_sorts_single_message_correctly(self):
        msg = self.make_message('Sun, 21 Feb 2016 11:56:07 +0200')
        thread = distixlib.MessageThread()
        thread.add_message(msg)
        self.assertEqual(thread.get_messages_in_date_order(), [msg])

    def test_sorts_two_messages_added_in_date_order_correctly(self):
        older = self.make_message('Sun, 21 Feb 2016 11:56:07 +0200')
        newer = self.make_message('Sun, 21 Feb 2016 11:56:16 +0200')
        thread = distixlib.MessageThread()
        thread.add_message(older)
        thread.add_message(newer)
        self.assertEqual(thread.get_messages_in_date_order(), [older, newer])

    def test_sorts_two_messages_added_in_reverse_order_correctly(self):
        older = self.make_message('Sun, 21 Feb 2016 11:56:07 +0200')
        newer = self.make_message('Sun, 21 Feb 2016 11:56:16 +0200')
        thread = distixlib.MessageThread()
        thread.add_message(newer)
        thread.add_message(older)
        self.assertEqual(thread.get_messages_in_date_order(), [older, newer])
