# Copyright 2014  Lars Wirzenius
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# =*= License: GPL-3+ =*=


import logging

import distixlib


class CannotLoadMetadataError(distixlib.StructuredError):

    msg = "Couldn't load metadata from {filename}: {errno}: {strerror}"


class MetadataLoader(object):

    def load_from_file(self, filename):
        try:
            with self._open_file(filename) as f:
                text = f.read()
        except EnvironmentError as e:
            logging.error('Opening or reading %s: %s', filename, e)
            raise distixlib.CannotLoadMetadataError(
                filename=filename, errno=e.errno, strerror=e.strerror)

        serialiser = distixlib.MetadataSerialiser()
        return serialiser.deserialise(text)

    def _open_file(self, filename, mode='r'):  # pragma: no cover
        return open(filename, mode)
