# Copyright 2014  Lars Wirzenius
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# =*= License: GPL-3+ =*=


import logging

import distixlib


class CannotSaveMetadataError(distixlib.StructuredError):

    msg = "Can't save metadata to {filename}: {errno}: {strerror}"


class MetadataSaver(object):

    def save_to_file(self, filename, metadata):
        serialiser = distixlib.MetadataSerialiser()
        text = serialiser.serialise(metadata)

        try:
            with self._open_file(filename, 'w') as f:
                f.write(text)
        except EnvironmentError as e:
            logging.error('Opening or reading %s: %s', filename, str(e))
            raise distixlib.CannotSaveMetadataError(
                filename=filename, errno=e.errno, strerror=e.strerror)

    def _open_file(self, filename, mode):  # pragma: no cover
        return open(filename, mode)
