# Copyright 2017  Lars Wirzenius
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# =*= License: GPL-3+ =*=


import email
import unittest

import distixlib


class GetIdFromMessageTests(unittest.TestCase):

    def test_returns_empty_list_if_no_ids(self):
        msg = email.message_from_string('''\
From: user@example.com
To: other@example.com
Subject: O, Romeo

Wherefore art thou?
''')

        self.assertEqual(distixlib.get_ids_from_message(msg), set())

    def test_returns_id_from_message_id(self):
        msg_text = '''\
From: user@example.com
To: other@example.com
Subject: O, Romeo
Message-Id: <capulet123@verona>

Wherefore art thou?
'''

        msg = email.message_from_string(msg_text)
        self.assertEqual(
            distixlib.get_ids_from_message(msg), set(['capulet123@verona']))

    def test_returns_ids_from_references(self):
        msg_text = '''\
From: user@example.com
To: other@example.com
Subject: O, Romeo
References: <capulet123@verona>,  <capulet456@verona>

Wherefore art thou?
'''

        msg = email.message_from_string(msg_text)
        self.assertEqual(
            distixlib.get_ids_from_message(msg),
            set(['capulet123@verona', 'capulet456@verona']))

    def test_returns_ids_from_in_reply_to(self):
        msg_text = '''\
From: user@example.com
To: other@example.com
Subject: O, Romeo
In-Reply-To: <capulet123@verona>,  <capulet456@verona>

Wherefore art thou?
'''

        msg = email.message_from_string(msg_text)
        self.assertEqual(
            distixlib.get_ids_from_message(msg),
            set(['capulet123@verona', 'capulet456@verona']))
