# Copyright 2014  Lars Wirzenius
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# =*= License: GPL-3+ =*=


import os
import shutil
import tempfile
import unittest

import distixlib


class RepositoryTests(unittest.TestCase):

    def setUp(self):
        self.tempdir = tempfile.mkdtemp()
        self.repodir = os.path.join(self.tempdir, 'repo')

    def tearDown(self):
        shutil.rmtree(self.tempdir)

    def test_invents_ticket_ids(self):
        repo = distixlib.Repository(self.tempdir)
        id1 = repo.invent_new_ticket_id()
        id2 = repo.invent_new_ticket_id()
        self.assertNotEqual(id1, id2)

    def test_creates_repository(self):
        self.assertFalse(os.path.exists(self.repodir))
        repo = distixlib.Repository(self.repodir)
        repo.create('test repo')
        self.assertTrue(os.path.isdir(self.repodir))
        self.assertEqual(repo.get_description(), 'test repo')

    def test_opens_ticket_store(self):
        repo = distixlib.Repository(self.tempdir)
        ticket_store = repo.open_ticket_store(distixlib.tickets_dir_name)
        self.assertEqual(type(ticket_store), distixlib.TicketStore)

    def test_doesnt_exit_if_working_tree_is_clean(self):
        repo = distixlib.Repository(self.repodir)
        repo.create('desc')
        self.assertEqual(repo.require_clean_working_tree(), None)

    def test_exits_program_if_working_tree_is_dirty(self):
        repo = distixlib.Repository(self.repodir)
        repo.create('desc')
        with open(os.path.join(self.repodir, 'extra-file'), 'w'):
            pass
        with open('/dev/null', 'w') as devnull:
            with self.assertRaises(SystemExit):
                repo.require_clean_working_tree(stderr=devnull)
